@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.32";
+our $VERSION = "1.33";
 
 use v5.14;
 use warnings;
@@ -456,7 +456,7 @@ sub table_out {
     return unless @_;
     my $split = do {
 	if ($obj->separator eq ' ') {
-	    $obj->ignore_space ? ' ' : qr/ /;
+	    $obj->ignore_space ? ' ' : qr/\s+/;
 	} else {
 	    qr/[\Q$obj->{separator}\E]/;
 	}
