@@ -159,6 +159,32 @@ my %template = (
 		    "╯"   ],
 	bottom =>     "─",
     },
+    inner_box => {
+	top    =>   "▄",
+	left   => [ "▗" ,
+		    "▐" ,
+		    "▝" ],
+	center => [ "▖▗" ,
+		    "▌▐" ,
+		    "▘▝" ],
+	right  => [ "▖"  ,
+		    "▌"  ,
+		    "▘" ],
+	bottom =>   "▀",
+    },
+    outer_box => {
+	top    =>   "▀",
+	left   => [ "▛"  ,
+		    "▌"  ,
+		    "▙" ],
+	center => [ "▜▛" ,
+		    "▐▌" ,
+		    "▟▙" ],
+	right  => [ "▜" ,
+		    "▐" ,
+		    "▟" ],
+	bottom =>   "▄",
+    },
     frame => {
 	top    =>    "─",
 	bottom =>    "─",
